==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/ExecEnvVarBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ExecEnvVarBuilder extends io.fabric8.kubernetes.api.model.ExecEnvVarFluentImpl<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ExecEnvVar,io.fabric8.kubernetes.api.model.ExecEnvVarBuilder>{
  public ExecEnvVarBuilder() {
    this(false);
  }
  public ExecEnvVarBuilder(java.lang.Boolean validationEnabled) {
    this(new ExecEnvVar(), validationEnabled);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent) {
    this(fluent, false);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ExecEnvVar(), validationEnabled);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent,io.fabric8.kubernetes.api.model.ExecEnvVar instance) {
    this(fluent, instance, false);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent,io.fabric8.kubernetes.api.model.ExecEnvVar instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVar instance) {
    this(instance,false);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVar instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ExecEnvVar build() {
    ExecEnvVar buildable = new ExecEnvVar(fluent.getName(),fluent.getValue());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExecEnvVarBuilder that = (ExecEnvVarBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/ExecEnvVarBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ExecEnvVarBuilder extends io.fabric8.kubernetes.api.model.ExecEnvVarFluentImpl<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ExecEnvVar,io.fabric8.kubernetes.api.model.ExecEnvVarBuilder>{
  public ExecEnvVarBuilder() {
    this(false);
  }
  public ExecEnvVarBuilder(java.lang.Boolean validationEnabled) {
    this(new ExecEnvVar(), validationEnabled);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent) {
    this(fluent, false);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ExecEnvVar(), validationEnabled);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent,io.fabric8.kubernetes.api.model.ExecEnvVar instance) {
    this(fluent, instance, false);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent,io.fabric8.kubernetes.api.model.ExecEnvVar instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVar instance) {
    this(instance,false);
  }
  public ExecEnvVarBuilder(io.fabric8.kubernetes.api.model.ExecEnvVar instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ExecEnvVarFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ExecEnvVar build() {
    ExecEnvVar buildable = new ExecEnvVar(fluent.getName(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExecEnvVarBuilder that = (ExecEnvVarBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
